pub struct HostControllerSetLocalNameRequest {
pub name: Option<String>,
/* private fields */
}Fields
name: Option<String>Trait Implementations
Sourceimpl Clone for HostControllerSetLocalNameRequest
impl Clone for HostControllerSetLocalNameRequest
Sourcefn clone(&self) -> HostControllerSetLocalNameRequest
fn clone(&self) -> HostControllerSetLocalNameRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<HostControllerSetLocalNameRequest, D> for HostControllerSetLocalNameRequest
impl<D: ResourceDialect> Decode<HostControllerSetLocalNameRequest, D> for HostControllerSetLocalNameRequest
Sourceimpl Default for HostControllerSetLocalNameRequest
impl Default for HostControllerSetLocalNameRequest
Sourcefn default() -> HostControllerSetLocalNameRequest
fn default() -> HostControllerSetLocalNameRequest
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<HostControllerSetLocalNameRequest, D> for &HostControllerSetLocalNameRequest
impl<D: ResourceDialect> Encode<HostControllerSetLocalNameRequest, D> for &HostControllerSetLocalNameRequest
Sourceimpl PartialEq for HostControllerSetLocalNameRequest
impl PartialEq for HostControllerSetLocalNameRequest
Sourcefn eq(&self, other: &HostControllerSetLocalNameRequest) -> bool
fn eq(&self, other: &HostControllerSetLocalNameRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for HostControllerSetLocalNameRequest
impl TypeMarker for HostControllerSetLocalNameRequest
Sourcetype Owned = HostControllerSetLocalNameRequest
type Owned = HostControllerSetLocalNameRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for HostControllerSetLocalNameRequest
impl ValueTypeMarker for HostControllerSetLocalNameRequest
Sourcetype Borrowed<'a> = &'a HostControllerSetLocalNameRequest
type Borrowed<'a> = &'a HostControllerSetLocalNameRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for HostControllerSetLocalNameRequest
impl StructuralPartialEq for HostControllerSetLocalNameRequest