pub struct HostControllerStartPairingDelegateRequest {
pub input_capability: Option<InputCapability>,
pub output_capability: Option<OutputCapability>,
/* private fields */
}Fields
input_capability: Option<InputCapability>Required. Set based on the ability of the host to enter responses to pairing requests.
See [fuchsia.bluetooth.sys/InputCapability].
output_capability: Option<OutputCapability>Required. Set based on the ability of the host to display information to the user
initiating or accepting a pairing. See [fuchsia.bluetooth.sys/OutputCapability].